@@ -1,10 +1,10 @@
 /*
- * Copyright (C) 2010-2019 Red Hat, Inc.  All rights reserved.
+ * Copyright (C) 2010-2020 Red Hat, Inc.  All rights reserved.
  *
  * Authors: Fabio M. Di Nitto <fabbione@kronosnet.org>
  *          Federico Simoncelli <fsimon@kronosnet.org>
  *
- * This software licensed under GPL-2.0+, LGPL-2.0+
+ * This software licensed under LGPL-2.0+
  */
 
 #include "config.h"
@@ -77,7 +77,7 @@ int knet_host_add(knet_handle_t knet_h, knet_node_id_t host_id)
 	/*
 	 * set default host->name to host_id for logging
 	 */
-	snprintf(host->name, KNET_MAX_HOST_LEN - 1, "%u", host_id);
+	snprintf(host->name, KNET_MAX_HOST_LEN, "%u", host_id);
 
 	/*
 	 * initialize links internal data
@@ -226,7 +226,7 @@ int knet_host_set_name(knet_handle_t knet_h, knet_node_id_t host_id, const char
 	}
 
 	for (host = knet_h->host_head; host != NULL; host = host->next) {
-		if (!strncmp(host->name, name, KNET_MAX_HOST_LEN - 1)) {
+		if (!strncmp(host->name, name, KNET_MAX_HOST_LEN)) {
 			err = -1;
 			savederrno = EEXIST;
 			log_err(knet_h, KNET_SUB_HOST, "Duplicated name found on host_id %u",
@@ -235,7 +235,7 @@ int knet_host_set_name(knet_handle_t knet_h, knet_node_id_t host_id, const char
 		}
 	}
 
-	snprintf(knet_h->host_index[host_id]->name, KNET_MAX_HOST_LEN - 1, "%s", name);
+	snprintf(knet_h->host_index[host_id]->name, KNET_MAX_HOST_LEN, "%s", name);
 
 exit_unlock:
 	pthread_rwlock_unlock(&knet_h->global_rwlock);
@@ -331,7 +331,7 @@ int knet_host_get_id_by_host_name(knet_handle_t knet_h, const char *name,
 int knet_host_get_host_list(knet_handle_t knet_h,
 			    knet_node_id_t *host_ids, size_t *host_ids_entries)
 {
-	int savederrno = 0, err = 0;
+	int savederrno = 0;
 
 	if (!knet_h) {
 		errno = EINVAL;
@@ -355,8 +355,7 @@ int knet_host_get_host_list(knet_handle_t knet_h,
 	*host_ids_entries = knet_h->host_ids_entries;
 
 	pthread_rwlock_unlock(&knet_h->global_rwlock);
-	errno = err ? savederrno : 0;
-	return err;
+	return 0;
 }
 
 int knet_host_set_policy(knet_handle_t knet_h, knet_node_id_t host_id,
@@ -528,27 +527,6 @@ int knet_host_enable_status_change_notify(knet_handle_t knet_h,
 	return 0;
 }
 
-int _send_host_info(knet_handle_t knet_h, const void *data, const size_t datalen)
-{
-	ssize_t ret = 0;
-
-	if (knet_h->fini_in_progress) {
-		return 0;
-	}
-
-	ret = sendto(knet_h->hostsockfd[1], data, datalen, MSG_DONTWAIT | MSG_NOSIGNAL, NULL, 0);
-	if (ret < 0) {
-		log_debug(knet_h, KNET_SUB_HOST, "Unable to write data to hostpipe. Error: %s", strerror(errno));
-		return -1;
-	}
-	if ((size_t)ret != datalen) {
-		log_debug(knet_h, KNET_SUB_HOST, "Unable to write all data to hostpipe. Expected: %zu, Written: %zd.", datalen, ret);
-		return -1;
-	}
-
-	return 0;
-}
-
 static void _clear_cbuffers(struct knet_host *host, seq_num_t rx_seq_num)
 {
 	int i;
@@ -563,6 +541,35 @@ static void _clear_cbuffers(struct knet_host *host, seq_num_t rx_seq_num)
 	}
 }
 
+static void _reclaim_old_defrag_bufs(struct knet_host *host, seq_num_t seq_num)
+{
+	seq_num_t head, tail; /* seq_num boundaries */
+	int i;
+
+	head = seq_num + 1;
+	tail = seq_num - (KNET_MAX_LINK + 1);
+
+	/*
+	 * expire old defrag buffers
+	 */
+	for (i = 0; i < KNET_MAX_LINK; i++) {
+		if (host->defrag_buf[i].in_use) {
+			/*
+			 * head has done a rollover to 0+
+			 */
+			if (tail > head) {
+				if ((host->defrag_buf[i].pckt_seq >= head) && (host->defrag_buf[i].pckt_seq <= tail)) {
+					host->defrag_buf[i].in_use = 0;
+				}
+			} else {
+				if ((host->defrag_buf[i].pckt_seq >= head) || (host->defrag_buf[i].pckt_seq <= tail)){
+					host->defrag_buf[i].in_use = 0;
+				}
+			}
+		}
+	}
+}
+
 /*
  * check if a given packet seq num is in the circular buffers
  * defrag_buf = 0 -> use normal cbuf 1 -> use the defrag buffer lookup
@@ -570,7 +577,7 @@ static void _clear_cbuffers(struct knet_host *host, seq_num_t rx_seq_num)
 
 int _seq_num_lookup(struct knet_host *host, seq_num_t seq_num, int defrag_buf, int clear_buf)
 {
-	size_t i, j; /* circular buffer indexes */
+	size_t head, tail; /* circular buffer indexes */
 	seq_num_t seq_dist;
 	char *dst_cbuf = host->circular_buffer;
 	char *dst_cbuf_defrag = host->circular_buffer_defrag;
@@ -580,19 +587,21 @@ int _seq_num_lookup(struct knet_host *host, seq_num_t seq_num, int defrag_buf, i
 		_clear_cbuffers(host, seq_num);
 	}
 
+	_reclaim_old_defrag_bufs(host, seq_num);
+
 	if (seq_num < *dst_seq_num) {
 		seq_dist =  (SEQ_MAX - seq_num) + *dst_seq_num;
 	} else {
 		seq_dist = *dst_seq_num - seq_num;
 	}
 
-	j = seq_num % KNET_CBUFFER_SIZE;
+	head = seq_num % KNET_CBUFFER_SIZE;
 
 	if (seq_dist < KNET_CBUFFER_SIZE) { /* seq num is in ring buffer */
 		if (!defrag_buf) {
-			return (dst_cbuf[j] == 0) ? 1 : 0;
+			return (dst_cbuf[head] == 0) ? 1 : 0;
 		} else {
-			return (dst_cbuf_defrag[j] == 0) ? 1 : 0;
+			return (dst_cbuf_defrag[head] == 0) ? 1 : 0;
 		}
 	} else if (seq_dist <= SEQ_MAX - KNET_CBUFFER_SIZE) {
 		memset(dst_cbuf, 0, KNET_CBUFFER_SIZE);
@@ -601,16 +610,16 @@ int _seq_num_lookup(struct knet_host *host, seq_num_t seq_num, int defrag_buf, i
 	}
 
 	/* cleaning up circular buffer */
-	i = (*dst_seq_num + 1) % KNET_CBUFFER_SIZE;
+	tail = (*dst_seq_num + 1) % KNET_CBUFFER_SIZE;
 
-	if (i > j) {
-		memset(dst_cbuf + i, 0, KNET_CBUFFER_SIZE - i);
-		memset(dst_cbuf, 0, j + 1);
-		memset(dst_cbuf_defrag + i, 0, KNET_CBUFFER_SIZE - i);
-		memset(dst_cbuf_defrag, 0, j + 1);
+	if (tail > head) {
+		memset(dst_cbuf + tail, 0, KNET_CBUFFER_SIZE - tail);
+		memset(dst_cbuf, 0, head + 1);
+		memset(dst_cbuf_defrag + tail, 0, KNET_CBUFFER_SIZE - tail);
+		memset(dst_cbuf_defrag, 0, head + 1);
 	} else {
-		memset(dst_cbuf + i, 0, j - i + 1);
-		memset(dst_cbuf_defrag + i, 0, j - i + 1);
+		memset(dst_cbuf + tail, 0, head - tail + 1);
+		memset(dst_cbuf_defrag + tail, 0, head - tail + 1);
 	}
 
 	*dst_seq_num = seq_num;
