@@ -16,6 +16,7 @@
 #include <stdlib.h>
 
 #include "internals.h"
+#include "netutils.h"
 #include "logging.h"
 #include "transports.h"
 #include "links_acl.h"
@@ -29,15 +30,6 @@ struct ip_acl_match_entry {
 	struct ip_acl_match_entry *next;
 };
 
-/*
- * s6_addr32 is not defined in BSD userland, only kernel.
- * definition is the same as linux and it works fine for
- * what we need.
- */
-#ifndef s6_addr32
-#define s6_addr32 __u6_addr.__u6_addr32
-#endif
-
 /*
  * IPv4 See if the address we have matches the current match entry
  */
@@ -148,7 +140,7 @@ int ipcheck_validate(void *fd_tracker_match_entry_head, struct sockaddr_storage
 	struct ip_acl_match_entry *match_entry = *match_entry_head;
 	int (*match_fn)(struct sockaddr_storage *checkip, struct ip_acl_match_entry *match_entry);
 
-	if (checkip->ss_family == AF_INET){
+	if (checkip->ss_family == AF_INET) {
 		match_fn = ip_matches_v4;
 	} else {
 		match_fn = ip_matches_v6;
