@@ -156,7 +156,7 @@ static void test(const char *model, const char *model2)
 
 	printf("Test knet_handle_crypto reconfig with %s/aes128/sha1 and normal key\n", model2);
 
-	current = knet_h->crypto_instance;
+	current = knet_h->crypto_instance[1];
 
 	memset(&knet_handle_crypto_cfg, 0, sizeof(struct knet_handle_crypto_cfg));
 	strncpy(knet_handle_crypto_cfg.crypto_model, model, sizeof(knet_handle_crypto_cfg.crypto_model) - 1);
@@ -174,7 +174,7 @@ static void test(const char *model, const char *model2)
 
 	flush_logs(logfds[0], stdout);
 
-	if (current == knet_h->crypto_instance) {
+	if (current == knet_h->crypto_instance[1]) {
 		printf("knet_handle_crypto failed to install new correct config: %s\n", strerror(errno));
 		knet_handle_free(knet_h);
 		flush_logs(logfds[0], stdout);
@@ -186,7 +186,7 @@ static void test(const char *model, const char *model2)
 
 	printf("Test knet_handle_crypto reconfig with %s/aes128/sha1 and normal key\n", model);
 
-	current = knet_h->crypto_instance;
+	current = knet_h->crypto_instance[1];
 
 	memset(&knet_handle_crypto_cfg, 0, sizeof(struct knet_handle_crypto_cfg));
 	strncpy(knet_handle_crypto_cfg.crypto_model, model, sizeof(knet_handle_crypto_cfg.crypto_model) - 1);
@@ -204,7 +204,7 @@ static void test(const char *model, const char *model2)
 
 	flush_logs(logfds[0], stdout);
 
-	if (current == knet_h->crypto_instance) {
+	if (current == knet_h->crypto_instance[1]) {
 		printf("knet_handle_crypto failed to install new correct config: %s\n", strerror(errno));
 		knet_handle_free(knet_h);
 		flush_logs(logfds[0], stdout);
@@ -216,7 +216,7 @@ static void test(const char *model, const char *model2)
 
 	printf("Test knet_handle_crypto reconfig with %s/aes129/sha1 and normal key\n", model);
 
-	current = knet_h->crypto_instance;
+	current = knet_h->crypto_instance[1];
 
 	memset(&knet_handle_crypto_cfg, 0, sizeof(struct knet_handle_crypto_cfg));
 	strncpy(knet_handle_crypto_cfg.crypto_model, model, sizeof(knet_handle_crypto_cfg.crypto_model) - 1);
@@ -234,7 +234,7 @@ static void test(const char *model, const char *model2)
 
 	flush_logs(logfds[0], stdout);
 
-	if (current != knet_h->crypto_instance) {
+	if (current != knet_h->crypto_instance[1]) {
 		printf("knet_handle_crypto failed to restore correct config: %s\n", strerror(errno));
 		knet_handle_free(knet_h);
 		flush_logs(logfds[0], stdout);
