@@ -101,11 +101,6 @@ static void test(void)
 	char send_buff[KNET_MAX_PACKET_SIZE];
 	struct sockaddr_storage lo;
 
-	if (make_local_sockaddr(&lo, 1) < 0) {
-		printf("Unable to convert loopback to sockaddr: %s\n", strerror(errno));
-		exit(FAIL);
-	}
-
 	memset(send_buff, 0, sizeof(send_buff));
 
 	printf("Test knet_send_sync incorrect knet_h\n");
@@ -296,7 +291,7 @@ static void test(void)
 		exit(FAIL);
 	}
 
-	if (knet_link_set_config(knet_h, 1, 0, KNET_TRANSPORT_UDP, &lo, &lo, 0) < 0) {
+	if (_knet_link_set_config(knet_h, 1, 0, KNET_TRANSPORT_UDP, 0, AF_INET, 0, &lo) < 0) {
 		printf("Unable to configure link: %s\n", strerror(errno));
 		knet_host_remove(knet_h, 1);
 		knet_handle_free(knet_h);
